﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using Syncfusion.SfDataGrid;
using UIKit;

namespace RTProPhone
{
    public class MyVC : UIViewController
    {
        public int verificationNo;
        private nfloat navHeight;

        public List<Noncoded> dataSource { get; set; }

        UISearchBar searchbar;
        SfDataGrid sfGrid;

        public MyVC (int verificationNo, nfloat navHeight)
        {
            this.verificationNo = verificationNo;
            this.navHeight = navHeight;
            this.dataSource = new OrdVerNoncodedRepository ().GetOrdVerNoncoded (verificationNo);

            nfloat statusBarHeight = UIApplication.SharedApplication.StatusBarFrame.Height;

            searchbar = new UISearchBar (new CoreGraphics.CGRect (0, statusBarHeight + navHeight + 1, Application.iPhoneWidth, 33));
            searchbar.OnEditingStarted += HandleOnEditingStarted;
            searchbar.TextChanged += HandleTextChanged;
            searchbar.CancelButtonClicked += HandleCancelButtonClicked;
            if (UIDevice.CurrentDevice.CheckSystemVersion(7, 1))
                searchbar.EnablesReturnKeyAutomatically = false;
            searchbar.Placeholder = "Search in All Columns";
            this.View.AddSubview(searchbar);

            sfGrid = new SfDataGrid (new CoreGraphics.CGRect (0, statusBarHeight + navHeight + searchbar.Frame.Height, Application.iPhoneWidth, Application.iPhoneHeight - statusBarHeight - navHeight - searchbar.Frame.Height - 2));
            sfGrid.AutoGenerateColumns = false;
            sfGrid.RowHeight = 50;
            sfGrid.AllowEditing = true;
            sfGrid.EditTapAction = TapAction.OnTap;
            sfGrid.ColumnSizer = ColumnSizer.Star;
            sfGrid.HeaderRowHeight = 40;
            sfGrid.ItemsSource = dataSource;

            GridTextColumn colCode = new GridTextColumn ();
            colCode.MappingName = "Code";
            colCode.HeaderText = "Code";
            colCode.HeaderTextAlignment = UIKit.UITextAlignment.Center;
            colCode.AllowEditing = true;

            GridTextColumn colDescription = new GridTextColumn ();
            colDescription.MappingName = "Description";
            colDescription.HeaderText = "Description";
            colDescription.HeaderTextAlignment = UIKit.UITextAlignment.Center;
            colDescription.AllowEditing = false;

            GridNumericColumn colCounted = new GridNumericColumn ();
            colCounted.MappingName = "Counted";
            colCounted.HeaderText = "Counted";
            colCounted.HeaderTextAlignment = UIKit.UITextAlignment.Center;
            colCounted.AllowEditing = false;

            GridNumericColumn colQuantity = new GridNumericColumn ();
            colQuantity.MappingName = "Quantity";
            colQuantity.HeaderText = "Qty";
            colQuantity.HeaderTextAlignment = UIKit.UITextAlignment.Center;
            colQuantity.AllowEditing = true;

            sfGrid.Columns.Add (colCode);
            sfGrid.Columns.Add (colDescription);
            sfGrid.Columns.Add (colCounted);
            sfGrid.Columns.Add (colQuantity);

            this.View.AddSubview (sfGrid);
        }

        void HandleOnEditingStarted (object sender, EventArgs e)
        {
            searchbar.SetShowsCancelButton(true, true);
        }
        void HandleTextChanged (object sender, UISearchBarTextChangedEventArgs e)
        {
            sfGrid.ItemsSource = dataSource.FindAll (x => x.Description.ToLower().Contains (e.SearchText.ToLower()));
        }
        void HandleCancelButtonClicked (object sender, EventArgs e)
        {
        	searchbar.ResignFirstResponder ();
        	searchbar.SetShowsCancelButton (false, true);
        	searchbar.ResignFirstResponder ();
        }
        internal void OnFilterChanged ()
        {
            /*
	        if (this.SfGrid.View != null) {
		        SfGrid.View.Filter = viewmodel.FilerRecords;
                    SfGrid.View.RefreshFilter();
            }
            */
        }
                                         
    }

    public class Noncoded
    {
        public string Code { get; set; }
        public string Description { get; set; }
        public string Department { get; set; }
        public int Counted { get; set; }
        public int Quantity { get; set; }
    }

    public class OrdVerNoncodedRepository
    {
        public List<Noncoded> GetOrdVerNoncoded (int verificationNo)
        {
        	List<Noncoded> ordVerNoncoded = new List<Noncoded> ();

            ordVerNoncoded.Add (new Noncoded () { Code = "12345", Description = "This is a est item", Counted = 5, Quantity = 0, Department = "DEPT01" });
            ordVerNoncoded.Add (new Noncoded () { Code = "12346", Description = "This is a est item eeeee", Counted = 3, Quantity = 0, Department = "DEPT01" });

        	return ordVerNoncoded;
        }
    }
}
